@@ -30,8 +30,4 @@ class BNode(Identifier):
         return (BNode, (str(self),))
 
     def __repr__(self):
-        if self.__class__ is BNode:
-            clsName = 'semantyk.core.identifier.bnode.BNode'
-        else:
-            clsName = self.__class__.__name__
-        return "%s('%s')" % (clsName, str(self))
\ No newline at end of file
+        return "BNode('%s')" % self
\ No newline at end of file
