@@ -7,20 +7,15 @@ Package | `__init__.py`
 Interactive & Visual Models for Data Representation.
 
 Daniel Bakas Amuchastegui\
-September 3, 2020
+September 3, 2019
 
 Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-from . import article
-from . import cell
-from . import file
-from . import graph
-from . import table
-
+from . import article, cell, file, graph, table
 from .article import *
 from .cell import *
 from .file import *
 from .graph import *
-from .table import *
\ No newline at end of file
+from .table import *
