@@ -11,12 +11,8 @@ Copyright © Semantyk 2020. All rights reserved.\
 –––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––––
 """
 
-from . import cell
-from . import dvm_extract_cell
-from . import multimedia_cell
-from . import text_cell
-
+from . import cell, dvm_extract_cell, multimedia_cell, text_cell
 from .cell import *
 from .dvm_extract_cell import *
 from .multimedia_cell import *
-from .text_cell import *
\ No newline at end of file
+from .text_cell import *
